|
How to release memory with EzXML
|
|
1
|
422
|
February 25, 2022
|
|
Same code run multiple times gives wildly different timings
|
|
39
|
2427
|
February 24, 2022
|
|
Accelerate pairwise damage computation
|
|
12
|
1202
|
February 24, 2022
|
|
Performance issues with CartesianIndices
|
|
5
|
759
|
February 24, 2022
|
|
Unexpected Allocations with Multiple Dispatch
|
|
2
|
533
|
February 23, 2022
|
|
Speeding up my code
|
|
7
|
902
|
February 23, 2022
|
|
How to create SMatrix from SVectors efficiently
|
|
1
|
543
|
February 23, 2022
|
|
How to efficiently calculate the Jacobian of the solution of a differential equation with respect to the initial conditions?
|
|
1
|
1225
|
February 21, 2022
|
|
This post claims that Julia is still 4-5 times slower than cython
|
|
38
|
5159
|
February 21, 2022
|
|
Why do take! and put! for channels allocate memory?
|
|
1
|
888
|
February 18, 2022
|
|
Avoiding Vectors of Abstract Types
|
|
22
|
4945
|
February 17, 2022
|
|
String Distance Calculations on GPU
|
|
4
|
2440
|
February 17, 2022
|
|
Calculating 2-point correlation of a large 3D array: `view` seems to make it worse?
|
|
2
|
667
|
February 17, 2022
|
|
How to capture an index in closure without allocating (or workaround)?
|
|
4
|
673
|
February 14, 2022
|
|
Performance of large sparse discrete map problems in DifferentialEquations
|
|
8
|
800
|
February 14, 2022
|
|
Channel monitoring/statistics
|
|
3
|
896
|
February 13, 2022
|
|
Random number iterator?
|
|
5
|
1179
|
February 13, 2022
|
|
Benchmarking function (using `@benchmark`) for various input sizes
|
|
2
|
630
|
February 12, 2022
|
|
Is there a fast way to evaluate the exp() function in Julia?
|
|
8
|
1978
|
February 12, 2022
|
|
Accelerate pairwise Lennard-Jones force computation
|
|
87
|
4516
|
February 12, 2022
|
|
Unexpected allocation when calling Julia function from C++
|
|
0
|
502
|
February 10, 2022
|
|
In-place multiplication is too much slower for ComplexF64
|
|
19
|
1528
|
February 10, 2022
|
|
Parallel Reductions with Zygote
|
|
11
|
2352
|
February 9, 2022
|
|
Unexpected allocations in loops
|
|
8
|
763
|
February 9, 2022
|
|
How to find details of the compiler and optimizations used by a specific installed version of Julia
|
|
11
|
957
|
February 9, 2022
|
|
"Cat" very slow for relativelly small tasks
|
|
2
|
506
|
February 9, 2022
|
|
Improving performance of recursions by avoiding closures
|
|
0
|
386
|
February 8, 2022
|
|
@printf strange performance behavior
|
|
1
|
414
|
February 8, 2022
|
|
What's the optimal setting for JULIA_NUM_THREADS on a Macbook Pro M1 Max
|
|
4
|
1176
|
February 8, 2022
|
|
Efficient way of doing linear regression
|
|
44
|
21872
|
February 7, 2022
|